pub enum CompileError {
InvalidFieldName {
field_name: String,
},
DefaultValueTooLong {
message: String,
},
DefaultValueTypeMismatch {
message: String,
},
NotRunViaCargo,
Io {
source: Error,
},
DeviceConfig {
source: LoadError,
},
}Expand description
Error returned when loading a device config
Variants
InvalidFieldName
Provided field name is not a valid rust ident
DefaultValueTooLong
Default value is too long for the container size
DefaultValueTypeMismatch
Default value does not match the object type
NotRunViaCargo
Missing cargo env vars
Io
An IO error occurred while writing generated code
DeviceConfig
An error occurred while loading the device config file